@@ -184,6 +184,13 @@ namespace Lum {
     // no code
   }
 
+  Combo::ComboPopup::~ComboPopup()
+  {
+    Forget(combo->table->GetTableView()->GetMouseSelectionAction());
+
+    combo->table=NULL;
+  }
+
   void Combo::ComboPopup::PreInit()
   {
     combo->table=new Lum::Table();
@@ -191,11 +198,12 @@ namespace Lum {
     combo->table->SetMinHeight(Base::Size::stdCharHeight,1);
 
     if (OS::display->GetTheme()->PopupsAreDialogs()) {
-      combo->table->SetMaxWidth(Base::Size::workHRel,100);
       combo->table->SetMaxHeight(Base::Size::workVRel,100);
     }
+    else if (OS::display->GetSize()<=OS::Display::sizeSmall) {
+      combo->table->SetMaxHeight(Base::Size::workVRel,80);
+    }
     else {
-      combo->table->SetMaxWidth(Base::Size::workHRel,80);
       combo->table->SetMaxHeight(Base::Size::workVRel,40);
     }
 
@@ -211,7 +219,7 @@ namespace Lum {
     Observe(combo->table->GetTableView()->GetMouseSelectionAction());
     Observe(GetPreOpenedAction());
 
-    SetMain(combo->table,true,false);
+    SetMain(combo->table,true,true);
 
     Popup::PreInit();
   }
@@ -372,21 +380,13 @@ namespace Lum {
       OS::ImageRef image=OS::display->GetImage(OS::Display::comboEditButtonImageIndex);
 
       if (imageRight) {
-        int    bx,by;
-
-        bx=this->x+value->GetOWidth();
-        by=this->y;
-
         image->Draw(draw,
-                    bx,by,
-                    image->GetWidth(),
-                    height);
+                    this->x+value->GetOWidth(),this->y+(height-image->GetHeight()) / 2);
       }
       else {
         image->Draw(draw,
-                    this->x,this->y,
-                    image->GetWidth(),
-                    height);
+                    this->x,
+                    this->y+(height-image->GetHeight()) / 2);
       }
     }
     else {
@@ -394,35 +394,31 @@ namespace Lum {
       OS::ImageRef divider=OS::display->GetImage(OS::Display::comboDividerImageIndex);
 
       if (imageRight) {
-        divider->Draw(draw,
-                      this->x+width-
-                      image->GetWidth()-
-                      OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)-
-                      divider->GetWidth(),
-                      this->y,
-                      image->GetWidth(),
-                      height);
+        divider->DrawStretched(draw,
+                               this->x+width-
+                               image->GetWidth()-
+                               OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)-
+                               divider->GetWidth(),
+                               this->y,
+                               image->GetWidth(),
+                               height);
 
         image->Draw(draw,
                     this->x+width-
                     image->GetWidth(),
-                    this->y+(height-image->GetHeight()) / 2,
-                    image->GetWidth(),
-                    image->GetHeight());
+                    this->y+(height-image->GetHeight()) / 2);
       }
       else {
         image->Draw(draw,
                     x,
-                    y+(height-image->GetHeight()) / 2,
-                    image->GetWidth(),
-                    image->GetHeight());
+                    this->y+(height-image->GetHeight()) / 2);
 
-        divider->Draw(draw,
-                      x+image->GetWidth()+
-                      OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject),
-                      this->y,
-                      image->GetWidth(),
-                      height);
+        divider->DrawStretched(draw,
+                               x+image->GetWidth()+
+                               OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject),
+                               this->y,
+                               image->GetWidth(),
+                               height);
 
       }
     }
