@@ -20,6 +20,7 @@
 #include <Lum/OS/Base/Window.h>
 
 #include <Lum/OS/Driver.h>
+#include <Lum/OS/Theme.h>
 
 namespace Lum {
   namespace OS {
@@ -447,6 +448,7 @@ namespace Lum {
         }
 
         open=false;
+        shown=false;
         onOpened=false;
         modalCount=0;
       }
@@ -495,6 +497,17 @@ namespace Lum {
       {
         OS::Window::EventMsg msg;
 
+        if (dynamic_cast<MouseEvent*>(event)!=NULL &&
+          dynamic_cast<MouseEvent*>(event)->type==MouseEvent::down) {
+          oldButton=lastButton;
+          lastButton=thisButton;
+          thisButton=*dynamic_cast<MouseEvent*>(event);
+
+          oldPress=lastPress;
+          lastPress=thisPress;
+          thisPress.SetToNow();
+        }
+
         msg.event=event;
 
         eventAction->Trigger(msg);
@@ -855,6 +868,22 @@ namespace Lum {
         // no code
       }
 
+      bool Window::IsDoubleClicked() const
+      {
+        Lum::Base::SystemTime n(thisPress);
+
+        n.Sub(lastPress);
+
+        return ((unsigned long)(n.GetTime()*1000+n.GetMicroseconds()/1000)<=display->GetMultiClickTime())
+          && (lastButton.type==thisButton.type)
+          && (lastButton.qualifier==thisButton.qualifier);
+      }
+
+      const OS::MouseEvent& Window::GetLastButtonClickEvent() const
+      {
+        return lastButton;
+      }
+
       void Window::KeyboardGrabOn()
       {
         // no code
