@@ -822,7 +822,9 @@ namespace Lum {
 
           serviceName=std::string(dbusDomain)+"."+appName;
 
-          if (dbus_bus_request_name(connection,serviceName.c_str(),DBUS_NAME_FLAG_ALLOW_REPLACEMENT,&err)==-1) {
+          if (dbus_bus_request_name(connection,
+                                    serviceName.c_str(),
+                                    DBUS_NAME_FLAG_ALLOW_REPLACEMENT,&err)==-1) {
             //std::cerr << "Cannot request name '" << serviceName << "': "<< err.message << std::endl;
             dbus_error_free(&err);
           }
