@@ -1677,7 +1677,8 @@ namespace Lum {
             cliped=true;
           }
 
-          if (!object->HasBackground() || !object->GetBackground()->transparentBorder) {
+          if (!object->HasBackground() ||
+              !object->GetBackground()->transparentBorder) {
             draw->SubClipRegion(object->GetOX(),object->GetOY(),
                                 object->GetOWidth(),object->GetOHeight());
           }
@@ -1715,14 +1716,14 @@ namespace Lum {
         ch=h;
 
         // Normally everything should be layouted in the layouting phase, however
-        // not all objetc implement VisitChildren or call Layout manually for their children.
+        // not all object implement VisitChildren or call Layout manually for their children.
         if (!object->IsLayouted()) {
           object->Layout();
         }
 
         if (object->OIntersect(cx,cy,cw,ch)) {
           // TODO: Now, even if the object has a background it might not be necessary to draw it,
-          // because the to be drawn area is complete covered by one or more children (recursivly)
+          // because the "to be drawn area" is complete covered by one or more children (recursivly)
           // that all have their own background and no transparent border.
           if (object->HasBackground()) {
             ClipVisitor visitor;
@@ -1760,15 +1761,20 @@ namespace Lum {
           object->VisitChildren(*this,true);
           object->PostDrawChilds(draw);
         }
+
         return true;
       }
     };
 
-    if (!background.Valid() || (background.Valid() && background->transparentBorder)) {
+    if (!background.Valid() ||
+        (background.Valid() && background->transparentBorder)) {
       assert(parent!=NULL);
 
       parent->DrawBackground(draw,x,y,w,h);
-      return;
+
+      if (!background.Valid()) {
+        return;
+      }
     }
 
     assert(background.Valid());
@@ -2255,6 +2261,17 @@ namespace Lum {
     // no code
   }
 
+  /**
+    If true returned, this object requires scroll knobs to change the
+    adjustment. If false it returned, it is assumed that the widget itself has ways to change
+    the adjustment (for exmaple by using dragging) and no scroll knobs will be used
+    but possibly a simpler presentation.
+    */
+  bool Scrollable::RequiresKnobs() const
+  {
+    return true;
+  }
+
   void Scrollable::SetHAdjustment(Model::Adjustment* adjustment)
   {
     assert(adjustment!=NULL && adjustment->GetTopModel()!=NULL);
