@@ -19,10 +19,17 @@
 
 #include <Lum/Table.h>
 
+#include <Lum/OS/Behaviour.h>
+
+#include <Lum/Panel.h>
+#include <Lum/PosMarker.h>
+#include <Lum/Scroller.h>
+
 namespace Lum {
 
   Table::Table()
-  : object(NULL),hScroller(NULL),vScroller(NULL),
+  : object(NULL),
+    hScroller(NULL),vScroller(NULL),
     kineticScroller(new KineticScroller()),
     hVisible(false),vVisible(false),
     table(new TableView()),
@@ -31,8 +38,6 @@ namespace Lum {
   {
     SetBackground(OS::display->GetFill(OS::Display::scrolledBackgroundFillIndex));
 
-    SetCanFocus(true);
-
     headerModel->AddColumn(L"",Base::Size::pixel,32000,true);
 
     Observe(refreshAction);
@@ -48,12 +53,6 @@ namespace Lum {
 
   bool Table::VisitChildren(Visitor &visitor, bool onlyVisible)
   {
-    if (object!=NULL) {
-      if (!visitor.Visit(object)) {
-        return false;
-      }
-    }
-
     if (hScroller!=NULL && (!onlyVisible || hVisible)) {
       if (!visitor.Visit(hScroller)) {
         return false;
@@ -66,6 +65,12 @@ namespace Lum {
       }
     }
 
+    if (object!=NULL) {
+      if (!visitor.Visit(object)) {
+        return false;
+      }
+    }
+
     return true;
   }
 
@@ -160,18 +165,26 @@ namespace Lum {
     Observe(table->GetHAdjustment());
     Observe(table->GetVAdjustment());
 
-    vScroller=new Scroller(true);
+    if (!OS::display->GetBehaviour()->ScrollKnobActive() &&
+        !table->RequiresKnobs()) {
+      vScroller=new PosMarker(true);
+      hScroller=new PosMarker(false);
+    }
+    else {
+      vScroller=new Scroller(true);
+      hScroller=new Scroller(false);
+    }
+
     vScroller->SetParent(this);
     vScroller->SetFlex(false,true);
     vScroller->SetModel(table->GetVAdjustment());
-    vScroller->CalcSize();
 
-    hScroller=new Scroller(false);
     hScroller->SetParent(this);
     hScroller->SetFlex(true,false);
     hScroller->SetModel(table->GetHAdjustment());
-    hScroller->CalcSize();
 
+    hScroller->CalcSize();
+    vScroller->CalcSize();
     object->CalcSize();
 
     // Initial dimension equal to table dimension
@@ -185,6 +198,7 @@ namespace Lum {
     width=std::max(hScroller->GetOWidth(),width);
     minHeight+=hScroller->GetOHeight();
 
+
     // Add Vertical scroller
     minWidth+=vScroller->GetOMinWidth();
     width+=vScroller->GetOWidth();
@@ -198,27 +212,31 @@ namespace Lum {
 
   void Table::Layout()
   {
+    object->Resize(width-vScroller->GetOWidth(),
+                   height-hScroller->GetOHeight());
+    object->Layout();
+
     if (hVisible &&
         (!table->GetHAdjustment()->IsValid() ||
-         table->GetHAdjustment()->GetVisible()==table->GetHAdjustment()->GetTotal())) {
+         table->GetHAdjustment()->IsCompletelyVisible())) {
       hScroller->Hide();
       hVisible=false;
     }
     else if (!hVisible &&
              table->GetHAdjustment()->IsValid() &&
-             table->GetHAdjustment()->GetVisible()<table->GetHAdjustment()->GetTotal()) {
+             !table->GetHAdjustment()->IsCompletelyVisible()) {
       hVisible=true;
     }
 
     if (vVisible &&
         (!table->GetVAdjustment()->IsValid() ||
-         table->GetVAdjustment()->GetVisible()==table->GetVAdjustment()->GetTotal())) {
+         table->GetVAdjustment()->IsCompletelyVisible())) {
       vScroller->Hide();
       vVisible=false;
     }
     else if (!vVisible &&
              table->GetVAdjustment()->IsValid() &&
-             table->GetVAdjustment()->GetVisible()<table->GetVAdjustment()->GetTotal()) {
+             !table->GetVAdjustment()->IsCompletelyVisible()) {
       vVisible=true;
     }
 
@@ -240,6 +258,7 @@ namespace Lum {
     // Resize and position objects
 
     object->MoveResize(x,y,tWidth,tHeight);
+    object->Layout();
 
     if (hVisible) {
       hScroller->MoveResize(x,y+tHeight,tWidth,hScroller->GetOHeight());
@@ -273,7 +292,8 @@ namespace Lum {
       return false;
     }
 
-    if (kineticScroller->HandleMouseEvent(event)) {
+    if (!table->RequiresKnobs() &&
+        kineticScroller->HandleMouseEvent(event)) {
       return true;
     }
 
@@ -296,25 +316,28 @@ namespace Lum {
       }
       return;
     }
-    else if (model==refreshAction && refreshAction->IsFinished()) {
+    else if (model==refreshAction &&
+             refreshAction->IsFinished()) {
       if ((hVisible &&
            (!table->GetHAdjustment()->IsValid() ||
-            table->GetHAdjustment()->GetVisible()==table->GetHAdjustment()->GetTotal())) ||
+            table->GetHAdjustment()->IsCompletelyVisible())) ||
           (!hVisible &&
            table->GetHAdjustment()->IsValid() &&
-           table->GetHAdjustment()->GetVisible()<table->GetHAdjustment()->GetTotal()) ||
+           !table->GetHAdjustment()->IsCompletelyVisible()) ||
           (vVisible &&
            (!table->GetVAdjustment()->IsValid() ||
-            table->GetVAdjustment()->GetVisible()==table->GetVAdjustment()->GetTotal())) ||
+            table->GetVAdjustment()->IsCompletelyVisible())) ||
           (!vVisible &&
            table->GetVAdjustment()->IsValid() &&
-           table->GetVAdjustment()->GetVisible()<table->GetVAdjustment()->GetTotal())) {
+           !table->GetVAdjustment()->IsCompletelyVisible())) {
         SetRelayout();
         Redraw();
       }
     }
 
-    kineticScroller->Resync(model,msg);
+    if (!table->RequiresKnobs()) {
+      kineticScroller->Resync(model,msg);
+    }
 
     Group::Resync(model,msg);
   }
