@@ -84,6 +84,11 @@ namespace Lum {
     delete formatProvider;
   }
 
+  bool TableView::RequiresKnobs() const
+  {
+    return false;
+  }
+
   /**
     Return the cell under the given coordinates. Returns false if there is no
     cell at the given position.
@@ -1098,32 +1103,34 @@ namespace Lum {
 
   bool TableView::HandleMouseEvent(const OS::MouseEvent& event)
   {
-    size_t xc,yc;
-
-    if (!visible || !model.Valid() || !model->IsEnabled()) {
+    if (!visible ||
+        !model.Valid() ||
+        !model->IsEnabled() ||
+        !header.Valid()) {
       return false;
     }
 
     if (event.type==OS::MouseEvent::down && PointIsIn(event)) {
       if (event.button==OS::MouseEvent::button1) {
+        size_t xc,yc;
+
         if (GetCell(event.x,event.y,xc,yc) &&
             selection.Valid() &&
+            xc>=0 &&
+            xc<header->GetColumns() &&
+            yc>=1 &&
             yc<=model->GetRows()) {
 
-          selection->SelectCell(xc,yc);
-          OnMouseSelection();
-          if (GetWindow()->IsDoubleClicked()) {
-            size_t xl,yl;
-
-            if (PointIsIn(GetWindow()->GetLastButtonClickEvent()) &&
-                GetCell(GetWindow()->GetLastButtonClickEvent().x,
-                        GetWindow()->GetLastButtonClickEvent().y,
-                        xl,yl) &&
-                yl<=model->GetRows() && yc==yl) {
-
+          if (selection->IsCellSelected(xc+1,yc)) {
+            if (GetWindow()->IsDoubleClicked()) {
               ActionDoubleClick();
             }
           }
+          else {
+            selection->SelectCell(xc+1,yc);
+
+            OnMouseSelection();
+          }
 
           return true;
         }
